@@ -13,7 +13,7 @@ for (timeStep in c("daily", "weekly", "monthly", "annual")) {
   
   test_that(sprintf("changeTimeStep aggregates hourly data at %s timestep", timeStep), {
     
-    calc <- changeTimeStep(areas, timeStep, "hourly", opts = opts)
+    calc <- suppressWarnings(changeTimeStep(areas, timeStep, "hourly", opts = opts))
     read <- readAntares(select = "LOAD", timeStep = timeStep, showProgress = FALSE, mcYears = "all")
     
     tmp <- merge(calc, read[, .(area, timeId, mcYear, read = LOAD)], by = c("area", "timeId", "mcYear"))
@@ -34,7 +34,7 @@ test_that("changeTimeStep keeps attributes", {
 test_that("Aggregating desaggregated data should give the initial values.", {
   areasD <- readAntares(select = "LOAD", showProgress = FALSE, mcYears = "all", timeStep = "daily")
   areasH <- changeTimeStep(areasD, "hourly")
-  areasD2 <- changeTimeStep(areasH, "daily")
+  areasD2 <- suppressWarnings(changeTimeStep(areasH, "daily"))
   setorder(areasD, timeId, area, mcYear)
   setorder(areasD2, timeId, area, mcYear)
   expect_equal(areasD, areasD2)
@@ -42,7 +42,7 @@ test_that("Aggregating desaggregated data should give the initial values.", {
 
 test_that("changeTimeStep works on antaresData objects", {
   mydata <- readAntares("all", "all", mcYears = "all", showProgress = FALSE)
-  mydataAgg <- changeTimeStep(mydata, "daily")
+  mydataAgg <- suppressWarnings(changeTimeStep(mydata, "daily"))
   expect_equal(attr(mydataAgg, "timeStep"), "daily")
   expect_equal(attr(mydataAgg$areas, "timeStep"), "daily")
   expect_equal(attr(mydataAgg$links, "timeStep"), "daily")
